************
* SCRIPT: 1_process_fem_data.do
* PURPOSE: process output data from the Future Elderly Model
************

* Preamble (unnecessary when executing run.do)
run "$Longevity/scripts/programs/_config.do"

************
* Code begins
************

clear all
set more off

local FEM_data "$Longevity/data/FEM/no_inflation_or_mort_decline"
local output_dir "$Longevity/processed/fem"
cap mkdir "$Longevity/processed"
cap mkdir "`output_dir'"

foreach scen in baseline_cohort {

	***
	* Transition probabilities
	***
	use "`FEM_data'/`scen'_health_1yr.dta", clear
	ren l2health health_state
	rename phealth*_1yr phealth*
	drop if age>100

	* Correct rounding error issues #1: can only transition to higher-numbered states
	qui forval x = 2/20 {
		forval y = 1/`=`x'-1' {			
			assert abs(phealth`y')<0.00001 if health_state==`x'
			replace    phealth`y'=0        if health_state==`x'
		}
	}
	
	* Correct rounding error issues #2: can only transition to states with same or greater number of chronic conditions
	gen     num_cc = 1 if inlist(health_state,2,7,12,17)
	replace num_cc = 2 if inlist(health_state,3,8,13,18)  & mi(num_cc)
	replace num_cc = 3 if inlist(health_state,4,9,14,19)  & mi(num_cc)
	replace num_cc = 4 if inlist(health_state,5,10,15,20) & mi(num_cc)
	replace num_cc = 0 if mi(num_cc)

	levelsof health_state if num_cc==0, local(states)
	foreach s of local states {
		assert abs(phealth`s')<0.00000001 if inlist(num_cc,1,2,3,4)
		replace    phealth`s'=0           if inlist(num_cc,1,2,3,4)
	}

	levelsof health_state if num_cc==1, local(states)
	foreach s of local states {
		assert abs(phealth`s')<0.00000001 if inlist(num_cc,2,3,4)
		replace    phealth`s'=0           if inlist(num_cc,2,3,4)
	}

	levelsof health_state if num_cc==2, local(states)
	foreach s of local states {
		assert abs(phealth`s')<0.00000001 if inlist(num_cc,3,4)
		replace    phealth`s'=0           if inlist(num_cc,3,4)
	}		

	levelsof health_state if num_cc==3, local(states)
	foreach s of local states {
		assert abs(phealth`s')<0.000001 if inlist(num_cc,4)
		replace    phealth`s'=0          if inlist(num_cc,4)
	}
	
	* Correction factor for a small number of probabilities that don't always quite sum to 1
	egen tmp = rowtotal(phealth*)
	gen correction = 1/tmp		

	* FEM transition probabilities start at age 51. Set age 50=51.
	sort health_state age
	foreach v of varlist phealth* {
		replace `v' = `v'[_n+1] if age==50
		
		* In diabetes scenario, there are two age-85 states that don't have probs that sum to 100%
		if "`scen'"=="diabe_mort" replace `v' = `v'*correction if age==85
		
		assert inrange(`v',0,1)
	}
	drop tmp correction num_cc
	
	* Ensure probabilities sum to 1 for all ages
	egen tmp = rowtotal(phealth*)
	assert abs(tmp-1)<0.000002
	drop tmp
	sort health_state age
	outsheet using "`output_dir'/`scen'_transitions.csv", comma nol replace

	***
	* EQ-5d (quality of life) - starts at age 50
	***
	use "`FEM_data'/`scen'_eq5d_1yr.dta", clear
	ren l2health health_state
	ren eq5d quality
	drop if age>100

	assert inrange(quality,0,1)
	sort health_state age
	outsheet using "`output_dir'/`scen'_quality.csv", comma nol replace
	
	replace quality = 1
	outsheet using "`output_dir'/`scen'_quality_constant.csv", comma nol replace
	
	***
	* Mortality rates -- for incidence scenarios, use the baseline_cohort rates
	***
	local mort_input "`scen'"
	if strpos("`scen'","inc") local mort_input "baseline_cohort"
	use "`FEM_data'/`mort_input'_mort_1yr.dta", clear
	ren l2health health_state
	ren pdied_1yr pdied
	drop if age>100
	
	* Set age 50=51 for mortality.
	bysort health_state (age): replace pdied = pdied[_n+1] if age==50
	
	* Set mortality equal to 100% in the final year
	replace pdied = 1 if age==100
	
	assert inrange(pdied,0,1)
	sort health_state age
	outsheet using "`output_dir'/`scen'_mortality.csv", comma nol replace
	
	***
	* No medical spending (i.e., constant 3% rate of return)
	***
	drop pdied
	gen return = 0.03
	outsheet using "`output_dir'/`scen'_nospend_return.csv", comma replace nol	
	
	***
	* Medical spending - needs to be normalized by wealth, as estimated by model in setting with no medical spending ("wealth_by_age.dta"). Cap the highest possible spending rate at 95%.
	***	
	tempfile w
	local mort_base "`output_dir'/baseline_cohort_mortality.csv"
	local qual_base "`output_dir'/baseline_cohort_quality.csv"
	local trans_base "`output_dir'/baseline_cohort_transitions.csv"
	local rates_base "`output_dir'/baseline_cohort_nospend_return.csv"
	
	local target_vsl 6000000
	local gamma 1.25
	local outputfile "$Longevity/results/intermediate/wealth_calib_init_`gamma'.csv"
	rscript using "$Longevity/scripts/programs/vsl_stochastic_r_code_plusFullAnn/wealth_calibration_state1.R", args("`target_vsl'" "$Longevity" "`outputfile'" "`mort_base'" "`qual_base'" "`trans_base'" "`rates_base'" "`gamma'")
	insheet using "`outputfile'", comma clear
	noi tab x
	local initial_wealth = x	
	
	noi rscript using "$Longevity/scripts/programs/vsl_stochastic_r_code_plusFullAnn/wealth_by_age.R", args(`initial_wealth' "$Longevity" "`w'" "`mort_base'" "`qual_base'" "`trans_base'" "`rates_base'" `gamma')
	insheet using "`w'", clear
	save "$Longevity/results/intermediate/wealth_by_age.dta", replace
	
	* OOP
	use "`FEM_data'/`scen'_oopmd_1yr.dta", clear
	ren l2health health_state
	drop if age>100
	assert !mi(oopmd)		
	merge m:1 age using "$Longevity/results/intermediate/wealth_by_age.dta", assert(match) nogenerate
	gen spending = oopmd/wealth

	gen return = max(0.03 + ln(1-spending),-.95)
	assert !mi(return)

	keep age health_state return
	sort health_state age return
	order age health_state return
	outsheet using "`output_dir'/`scen'_oopmd_return.csv", comma replace nol
	
	* 20% wealth shock
	replace return = return + ln(1-.2) if health_state==14 & age==70
	outsheet using "`output_dir'/`scen'_s14age70_return.csv", comma replace nol
	
	* Total
	use "`FEM_data'/`scen'_totmd_1yr.dta", clear
	ren l2health health_state
	drop if age>100
	assert !mi(totmd)
	merge m:1 age using "$Longevity/results/intermediate/wealth_by_age.dta", assert(match) nogenerate
	gen spending = totmd/wealth

	gen return = max(0.03 + ln(1-spending),-.95)
	assert !mi(return)

	keep age health_state return
	sort health_state age return
	order age health_state return
	outsheet using "`output_dir'/`scen'_totmd_return.csv", comma replace nol
		
	***
	* Bequest motives
	***
	drop return
	gen bequest = 1.2
	sort health_state age bequest
	order age health_state bequest		
	outsheet using "`output_dir'/`scen'_bequest.csv", comma replace nol
}

* Initial states
use "$Longevity/data/FEM/healthstate_age50.dta", clear
ren l2health health_state
outsheet using "`output_dir'/age50_health.csv", comma replace nol

* Assume initial wealth at age 50 (which will be calibrated in a later script) is proportional to FEM earnings at age 50
use "$Longevity/data/FEM/income_wealth_age50.dta", clear
ren l2health health_state
ren iearnuc wealth
keep health_state wealth
outsheet using "`output_dir'/age50_wealth.csv", comma replace nol

** EOF
