************
* SCRIPT: 3_make_tables_figures.do
* PURPOSE: output the tables and figures used in the manuscript
************

* Preamble (unnecessary when executing run.do)
run "$Longevity/scripts/programs/_config.do"

************
* Code begins
************

tempfile t vsl_70
local FEM_data "$Longevity/data/FEM/no_inflation_or_mort_decline"
local FEM_input  "$Longevity/processed/fem"
local FEM_output "$Longevity/results/intermediate/base_1.25"

local texsave_settings "replace autonumber nofix"

*******
* Excel figures
*******
copy "$Longevity/data/figures/interior_solution_1corner.pdf" "$Longevity/results/figures/interior_solution_1corner.pdf", replace
copy "$Longevity/data/figures/interior_solution_2corners.pdf" "$Longevity/results/figures/interior_solution_2corners.pdf", replace


*******
* Heterogeneity in VSL 
*******

***
* Histogram of VSL at age 70
***
use "`FEM_output'/simulations_processed.dta", clear

* 22,214 healthy adults (state 1) at age 50
count if age==50
assert r(N)==22214

replace VSL = VSL/1000

summ VSL if age==70
local vsl_mean_age70 = trim("`: di %4.0fc r(mean)'")

graph twoway histogram VSL if age==70, graphregion(color(white)) xtitle("VSL (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylabel(,format(%12.0fc)) || function y=`vsl_mean_age70', horizontal range(0 4100) lwidth(medthick) legend(off) text(4220 2400 "Mean = `vsl_mean_age70'", place(e))
graph export "$Longevity/results/figures/mc_vsl_age70.pdf", replace as(pdf)

***
* Spaghetti plot of VSL, by age
***
local pct_stats
local graph_nms
local lwidth
local lcolor
local cmd 
foreach x of numlist 1 2 3 4 5(5)95 96 97 98 99 {
	local pct_stats "`pct_stats' (p`x') p`x'_VSL=VSL"
	
	local graph_nms "`graph_nms' p`x'_VSL"
	local lwidth "`lwidth' medium"
	local lcolor "`lcolor' blue*0.2"	
	local cmd "`cmd' || line p`x'_VSL age, lwidth(medium) lcolor(blue*0.2)"
}

collapse (mean) mean_VSL=VSL `pct_stats', by(age) fast

* "By age 70, the VSL inter-vigintile range spans \$1.9 to \$2.9 million."
assert abs(p5_VSL - 1918.0107)<1 if age==70
assert abs(p95_VSL - 2903.012)<1 if age==70

format mean_VSL %12.0fc
label var mean_VSL "Mean"
label var age "Age"
graph twoway `cmd' || line mean_VSL age, lwidth(thick) lcolor(blue) ytitle("VSL (thousands of dollars)", size(medlarge)) graphregion(color(white)) ylabel(0(2000)7000) xtitle("Age", size(medlarge)) legend(off)
graph export "$Longevity/results/figures/mc_vsl_variance.pdf", replace as(pdf)


*******
* Shocks
*******

* LE and QALY by age/state (descriptive stats)
insheet using "`FEM_output'/age_state_le_qaly.csv", comma clear
drop v1
replace v2 = v2+49
ren v2 age
ren v3 state
ren v4 LE
ren v5 QALE

assert QALE<LE
tempfile le_qaly
save "`le_qaly'", replace


* "Quality-adjusted life expectancy for a 70-year-old in perfect health is equal to 10.96 years."
keep if age==70 & state==1
assert abs(QALE-10.95534)<0.001

***
* VSL shocks -- use counterfactual values
***

use "`FEM_output'/simulations_processed_cf.dta", clear

merge m:1 age state using "`le_qaly'", assert(match using) keep(match) nogenerate keepusing(QALE LE)
ren vsl VSL
replace VSL = VSL/1000
replace vsl_prev = vsl_prev/1000
gen VSLY = VSL/QALE
label var VSLY "VSL per QALY (thousands of dollars)"
ren QALE QALE_current

ren state state_current
ren state_prev state
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) nogenerate keepusing(QALE)
gen vsly_prev = vsl_prev/QALE
ren state state_prev
ren QALE QALE_prev
ren state_current state
ren QALE_current QALE

bysort sim (age): gen shock = state!=state[_n-1] & _n!=1
gen vsl_diff  = VSL  - vsl_prev if shock==1
gen vsly_diff = VSLY - vsly_prev if shock==1

count if shock==1
local num_shocks = trim("`: di %11.0gc r(N)'")
assert "`num_shocks'"=="57,981"

* On average, a health shock increases VSL by \$130,000 (2.8\%).
format vsl_diff %12.0fc
summ vsl_diff, detail
assert abs(126.7833 - r(mean))<1
local vsl_diff_mean = trim("`: di %4.1fc r(mean)'")

summ VSL if shock[_n+1]==1
assert abs(126.7833/r(mean) - .03308277)<.0001
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")

graph twoway histogram vsl_diff if shock==1, graphregion(color(white)) xtitle("Change in VSL (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylabel(,format(%12.0fc)) || function y=`vsl_diff_mean', horizontal range(0 26000) lwidth(medthick) legend(off) note("Mean VSL in year prior to shock = `mean_prior_yr' (thousands of dollars)") text(26815.74178872469 75 "Mean = `vsl_diff_mean'", place(e))
graph export "$Longevity/results/figures/mc_vsl_change.pdf", replace as(pdf)

* health shocks increase VSL per QALY by \$88,000 (25\%)
summ vsly_diff, detail
assert abs(87.71895 - r(mean))<0.5
local vsly_diff_mean = trim("`: di %4.1fc r(mean)'")

* The distribution is skewed to the right, with the value of a QALY rising by over \$200,000 (58\%) in 5\% of cases.
assert abs(r(p95) -  200.7)<0.5

summ VSLY if shock[_n+1]==1
assert abs(87.71895/r(mean)-.2522777)<0.001
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")

graph twoway histogram vsly_diff if shock==1, graphregion(color(white)) xtitle("Change in VSL/QALY (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylabel(,format(%12.0fc)) || function y=`vsly_diff_mean', horizontal range(0 25000) lwidth(medthick) legend(off) note("Mean VSL/QALY in year prior to shock = `mean_prior_yr' (thousands of dollars)") text(25800 25 "Mean = `vsly_diff_mean'", place(e))
graph export "$Longevity/results/figures/mc_vsly_change.pdf", replace as(pdf)

***
* VSL and VSL per QALY at age 70
***
keep if age==70

collapse (mean) VSL VSLY, by(state LE QALE) fast
preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	keep state_sick QALE_sick vsi VSIY
	save "`vsl_70'", replace
restore

format VSL %12.0fc
label var LE "Life expectancy"
label var VSL "VSL (thousands of dollars)"
sort QALE
label var VSLY "VSL per QALY (thousands of dollars)"
label var VSL "VSL"
label var VSLY "VSL per QALY"
local yaxis1_options `"yscale(range(0 500) axis(1)) ylabel(0(500)3000, axis(1)) ytitle("VSL (thousands of dollars)", size(medlarge))"'
local yaxis2_options `"yscale(range(0 500) axis(2)) ylabel(0(250)750, axis(2)) ytitle("VSL per QALY (thousands of dollars)", size(medlarge) axis(2))"'
graph twoway connected VSL QALE, yaxis(1) `yaxis1_options' lcolor(blue) lwidth(medthick) mcolor(blue) msymbol(square) lpattern(shortdash) || connected VSLY QALE, yaxis(2) `yaxis2_options' lpattern(solid) lwidth(medthick) lcolor(red) mcolor(red) graphregion(color(white)) xtitle("Life expectancy at age 70 (QALYs)", size(medlarge))
graph export "$Longevity/results/figures/mc_vsl_vsly_age70.pdf", replace as(pdf)

* Individuals in the worst health state have an average VSL per QALY of \$630,000, over 2.4 times higher than individuals in the healthiest state, where VSL per QALY is \$260,000
assert abs(VSLY-259.5642)<0.1 if state==1
assert abs(VSLY-631.446)<0.1 if state==20
assert abs(631.446/259.5642 - 2.4327161)<.01

* Life expectancy in worst health state: 2.6 QALYs
* Life expectancy in best health state: 11 QALYs
assert abs(QALE-2.556804)<0.01 if state==20
assert abs(QALE-10.95534)<0.01 if state==1



***
* VSI at age 70 and state 1
***
use "`FEM_output'/sims_vsi_age70_processed.dta", clear
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_sick

ren state state_sick
gen state = 1
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_healthy

gen diff = QALE_healthy - QALE_sick

assert diff<0.001 if state_sick==1
drop if state_sick==1

assert diff>0
assert diff<QALE_healthy
gen VSIY = vsi/diff

collapse (mean) VSIY vsi, by(state_sick QALE_sick) fast
replace VSIY = VSIY/1000
replace vsi = vsi/1000

append using "`vsl_70'"

sort QALE_sick

* "preventing the onset of a severe illness is worth modestly more than preventing the onset of a mild illness, with values ranging from \$194,000 per QALY to \$227,000"
* Reducing the risk of death (\$260,000 per QALY) is worth 16\% more on a per QALY basis than reducing the risk of transitioning to health state 2 (\$224,000 per QALY), the state reflecting the mildest illness (9.7 QALYs)
assert abs(VSIY-259.5642)<0.01 if state_sick==21
assert abs(VSIY-224.3405)<0.01 if state_sick==2
assert abs(259.5642/224.3405 - 1.15701)<0.0001
assert abs(QALE_sick-9.737671)<0.001 if state_sick==2

* A marginal reduction in the probability of transitioning to the worst health state (2.6 QALYs) is worth about \$2.1 million
assert abs(QALE_sick - 2.556804)<0.01 if state_sick==20
assert abs(vsi - 2063.042)<1 if state_sick==20

* VSL, which is a special case of VSI where life expectancy is 0 years in the sick state, is \$2.8 million. 
assert abs(vsi - 2843.613)<0.01 if state_sick==21


format VSIY %12.0fc
label var VSIY "VSI per QALY (thousands of dollars)"

format vsi %12.0fc
label var vsi "VSI"
local yaxis1_options `"yscale(range(0 500) axis(1)) ylabel(0(500)3000, axis(1)) ytitle("VSI (thousands of dollars)", size(medlarge))"'
local yaxis2_options `"yscale(range(0 250) axis(2)) ylabel(0(50)250, axis(2)) ytitle("VSI per QALY (thousands of dollars)", size(medlarge) axis(2))"'
graph twoway connected vsi QALE_sick, yaxis(1) `yaxis1_options' lcolor(blue) lwidth(medthick) mcolor(blue) msymbol(square) lpattern(shortdash) || connected VSIY QALE_sick, yaxis(2) `yaxis2_options' lpattern(solid) lwidth(medthick) lcolor(red) mcolor(red) graphregion(color(white)) text(-245 0.1 "(death)", place(e)) xtitle("Life expectancy when ill (QALYs)", size(medlarge))
graph export "$Longevity/results/figures/mc_vsi_vsiy_age70.pdf", replace as(pdf)


*******
* Spending shocks
*******

use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear
keep  age c_oopmd VSL_oopmd VSL_cf1_oopmd  VSL_cf2_oopmd
order age c_oopmd VSL_oopmd

foreach v in c_oopmd VSL_oopmd VSL_cf1_oopmd VSL_cf2_oopmd {
	replace `v' = `v'/1000
}
summ VSL_cf1_oopmd if age==60
local cf1 = r(mean)

summ VSL_cf2_oopmd if age==70
local cf2 = r(mean)

label var c_oopmd "Consumption"
label var VSL_oopmd "VSL"
label var age "Age"

format c_oopmd %12.0fc
format VSL_oopmd %12.0fc

keep if age<=75
local graph_options `"graphregion(fcolor(white)) legend(label(3 "Counterfactual VSL"))"'
graph twoway line c_oopmd age, lpattern(shortdash) lwidth(thick) lcolor(blue) || line VSL_oopmd age, yaxis(2) ytitle("Consumption (thousands of dollars)", axis(1) size(medlarge)) ytitle("VSL (thousands of dollars)", axis(2) size(medlarge)) lwidth(thick thick) lpattern(solid dot) lcolor(red black) `graph_options' yscale(range(0) axis(1)) yscale(range(0) axis(2)) ylabel(0(10)110, axis(1))  ylabel(0(1000)7000, axis(2)) || scatteri `cf1' 60 `cf2' 70, yaxis(2) msymbol(X) msize(medlarge) mcolor(black) xtitle("Age", size(medlarge))
graph export "$Longevity/results/figures/c_vsl_shock.pdf", replace as(pdf)


* VSL rises from \$2.6 million to \$3.1 million following the severe health shock at age 70
assert abs(VSL_cf2_oopmd-2631)<10 if age==70
assert abs(VSL_oopmd-3100)<10 if age==70

***********************************
* Descriptive stats table: transition probs, quality of life, spending, and life expectancy
***********************************
insheet using "`FEM_input'/baseline_cohort_transitions.csv", comma clear
keep if inlist(age,50,70)
gen exit_prob = .
forval x = 1/20 {
	replace exit_prob = 1-phealth`x' if health_state==`x'
}
keep age health_state exit_prob
reshape wide exit_prob, i(health_state) j(age)
save "`t'", replace

use "`FEM_data'/baseline_cohort_oopmd_1yr.dta", clear
keep if inlist(age,50,70)
ren l2health health_state
reshape wide oopmd, i(health_state) j(age)
merge 1:1 health_state using "`t'", assert(match) nogenerate
save "`t'", replace

insheet using "`FEM_input'/baseline_cohort_quality.csv", comma clear
keep if inlist(age,50,70)
reshape wide quality, i(health_state) j(age)
merge 1:1 health_state using "`t'", assert(match) nogenerate
save "`t'", replace


use "`le_qaly'", clear
keep if inlist(age,50,70)
reshape wide LE QALE, i(state) j(age)
ren state health_state
merge 1:1 health_state using "`t'", assert(match) nogenerate

* Format and output table
foreach v of varlist exit* {
	replace `v' = `v'*100
}

save "$Longevity/results/intermediate/summary_stats.dta", replace

use "$Longevity/results/intermediate/summary_stats.dta", clear


tostring LE*, replace format(%12.1fc) force
tostring QALE*, replace format(%12.1fc) force
tostring qual*, replace format(%5.2fc) force
tostring oop*, replace format(%6.0fc) force
tostring exit*, replace format(%5.1fc) force

foreach v of varlist exit* {
*	replace `v' = `v' + "\%"
}

foreach v of varlist oop* {
*	replace `v' = "\$" + `v'
}

tostring health_state, replace
replace health_state = "1 (healthy)" if health_state=="1"

gen adls = floor((_n-1)/5)
gen cc = mod(_n-1,5)
tostring adls cc, replace
replace adls = "3+" if adls=="3"
replace cc = "4+" if cc == "4"

gen adls_cc = adls + " / " + cc
drop adls cc
order health_state adls_cc

label var health_state "Health state"
label var adls_cc "ADLs / CCs"
foreach v of varlist *50 {
	label var `v' "Age 50"
}
foreach v of varlist *70 {
	label var `v' "Age 70"
}
order health_state adls_cc LE50 LE70 QALE50 QALE70

local title "Summary means for the Future Elderly Model data, by health state"
local headerlines "& & \multicolumn{2}{c}{Life expectancy (years)}  & \multicolumn{2}{c}{Life expectancy (QALYs)} & \multicolumn{2}{c}{Quality of life (EQ-5D)} & \multicolumn{2}{c}{Medical spending (\\\\\\\\\$)} & \multicolumn{2}{c}{Exit probability (\%)}" "\cmidrule(lr){3-4} \cmidrule(lr){5-6} \cmidrule(lr){7-8} \cmidrule(lr){9-10} \cmidrule(lr){11-12}"
local fn "Notes: This table reports selected means for the health data obtained from the Future Elderly Model (FEM). Column (1) reports the number of impaired activities of daily living (ADLs) and the number of chronic conditions (CCs), which together define a health state. Columns (2)--(3) report life expectancy in years. Columns (4)--(5) reports life expectancy in QALYs, which is calculated using equation \eqref{E - QALE} with a 3\% discount rate. Columns (6)--(7) report average quality of life as measured by the EQ-5D, where 1 indexes perfect health. Columns (8)--(9) report average annual out-of-pocket medical spending, which includes all inpatient, outpatient, prescription, and long-term care spending not covered by insurance. Columns (10)--(11) report the percentage probability that an individual transitions to a different health state in the following year (excluding death). All impaired ADLs and chronic conditions are permanent, i.e., individuals can transition only to higher-numbered health states. Additional details about the FEM are available in Appendix \ref{S - Appendix - Data}."
texsave using "$Longevity/results/tables/summary_stats.tex", label(T - summary_stats) size(footnotesize) landscape align(llCCCCCCCCCC) footnote("`fn'") title("`title'") headerlines("`headerlines'") varlabels `texsave_settings'


***********************************
* Spending summary statistics figure
***********************************

use "`FEM_data'/baseline_cohort_oopmd_1yr.dta", clear
ren l2health health_state
keep if age<99
replace oopmd = oopmd/1000

keep if inlist(health_state,1,20)

reshape wide oopmd, i(age) j(health_state)

label var oopmd1 "Healthy (state 1)"
label var oopmd20 "Sick (state 20)"

graph twoway line oopmd1 oopmd20 age, lpattern(solid shortdash) lwidth(thick thick) lcolor(red blue) xtitle("Age", size(medlarge)) ytitle("Spending (thousands of dollars)", size(medlarge)) graphregion(fcolor(white)) 
graph export "$Longevity/results/figures/medical_spending.pdf", as(pdf) replace



***********************************
* Robustness checks
***********************************
local FEM_output "$Longevity/results/intermediate"
tempfile cons_vsl simulations vsiy

local replace
foreach scen in base_0.8 base_1.25 base_1.5 bequest_1.25 robustness_q_1.25 {
	
	***
	* consumption/VSL shock
	***
	use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear	
	gen scen = "`scen'"
	
	keep if age<=75
	replace c_oopmd = c_oopmd/1000
	replace VSL_oopmd = VSL_oopmd/1000
	label var age "Age"

	format c_oopmd %12.0fc
	format VSL_oopmd %12.0fc	
	
	if "`replace'"!="" append using "`cons_vsl'"
	save "`cons_vsl'", `replace'
	
	***
	* Simulations
	***
	use "`FEM_output'/`scen'/simulations_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) nogenerate

	replace VSL = VSL/1000
	gen VSLY = VSL/QALE
	label var VSLY "VSL per QALY (thousands of dollars)"
	
	gen VSLY_LE = VSL/LE
	label var VSLY_LE "VSL per LY (thousands of dollars)"

	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`simulations'"
	save "`simulations'", `replace'
	
	***
	* VSIY
	*** 
	use "`FEM_output'/`scen'/sims_vsi_age70_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_sick
	ren LE LE_sick

	ren state state_sick
	gen state = 1
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_healthy
	ren LE LE_healthy

	gen diff    = QALE_healthy - QALE_sick
	gen diff_LE = LE_healthy - LE_sick

	assert diff<0.001 if state_sick==1
	assert diff_LE<0.001 if state_sick==1
	drop if state_sick==1

	assert diff   >0
	assert diff_LE>0
	assert diff   <QALE_healthy
	assert diff_LE<LE_healthy

	replace vsi = vsi/1000
	gen VSIY    = vsi/diff
	gen VSIY_LE = vsi/diff_LE
	
	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`vsiy'"
	save "`vsiy'", `replace'	
	
	local replace replace
}

local graph_options `"legend(label(1 "{&gamma}=0.8") label(2 "{&gamma}=1.25 (baseline)") label(3 "{&gamma}=1.5") label(4 "Bequest")) graphregion(fcolor(white))"'
local common_opts "lwidth(thick) msize(medlarge)"
local plot1 "lpattern(shortdash)    lcolor(green) mcolor(green) msymbol(X)   `common_opts'"
local plot2 "lpattern(solid)        lcolor(red)   mcolor(red)   msymbol(circle)   `common_opts'"
local plot3 "lpattern(shortdash)    lcolor(blue)  mcolor(blue)  msymbol(square)   `common_opts'"
local plot4 "lpattern(longdash_dot) lcolor(black) mcolor(black) msymbol(triangle) `common_opts'"

***********************************
* First set of robustness figures: vary gamma and vary bequest motive
***********************************

* cons/vsl
use "`cons_vsl'", clear

graph twoway line c_oopmd age if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || line c_oopmd age if scen=="base_1.25", `plot2' || line c_oopmd age if scen=="base_1.5", `plot3' || line c_oopmd age if scen=="bequest_1.25", `plot4' `graph_options'
graph export "$Longevity/results/figures/robustness_consumption.pdf", replace as(pdf)

graph twoway line VSL_oopmd age if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || line VSL_oopmd age if scen=="base_1.25", `plot2' || line VSL_oopmd age if scen=="base_1.5", `plot3' || line VSL_oopmd age if scen=="bequest_1.25", `plot4' `graph_options'
graph export "$Longevity/results/figures/robustness_vsl.pdf", replace as(pdf)


* VSL per QALY at age 70
use "`simulations'" if age==70, clear
collapse (mean) VSL VSLY VSLY_LE, by(state LE QALE scen) fast

preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	gen LE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	gen VSIY_LE = vsi/LE
	keep *_sick vsi VSIY VSIY_LE scen
	save "`vsl_70'", replace
restore

sort scen QALE
label var QALE "Life expectancy at age 70 (QALYs)"
graph twoway connected VSLY QALE if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || connected VSLY QALE if scen=="base_1.25", `plot2' || connected VSLY QALE if scen=="base_1.5", `plot3' || connected VSLY QALE if scen=="bequest_1.25", `plot4' `graph_options'
graph export "$Longevity/results/figures/robustness_mc_vsly_age70.pdf", replace as(pdf)

* VSI per QALY at age 70
use "`vsiy'", clear

collapse (mean) VSIY, by(state_sick QALE_sick scen) fast
append using "`vsl_70'"

sort scen QALE_sick
format VSIY %12.0fc
label var QALE_sick "Life expectancy when ill (QALYs)"

graph twoway connected VSIY QALE_sick if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || connected VSIY QALE_sick if scen=="base_1.25", `plot2' || connected VSIY QALE_sick if scen=="base_1.5", `plot3' || connected VSIY QALE_sick if scen=="bequest_1.25", `plot4' `graph_options' text(172.5 0.1 "(death)", place(e))
graph export "$Longevity/results/figures/robustness_mc_vsiy_age70.pdf", replace as(pdf)


***********************************
* Second set of robustness figures: set quality of life = 1 and medical spending = 0
* Note: Here, everything is normalized by life expectancy rather than by quality-adjusted life expectancy
***********************************
local graph_options `"legend(label(1 "Baseline") label(2 "q=1, no medical spending")) graphregion(fcolor(white))"'

* cons/vsl
use "`cons_vsl'", clear

graph twoway line c_oopmd age if scen=="base_1.25", `plot2' ytitle("Thousands of dollars", size(medlarge)) || line c_oopmd age if scen=="robustness_q_1.25", `plot3'  `graph_options' xtitle("Age", size(medlarge))
graph export "$Longevity/results/figures/robustness2_consumption.pdf", replace as(pdf)

graph twoway line VSL_oopmd age if scen=="base_1.25", `plot2' ytitle("Thousands of dollars", size(medlarge)) || line VSL_oopmd age if scen=="robustness_q_1.25", `plot3' `graph_options' xtitle("Age", size(medlarge))
graph export "$Longevity/results/figures/robustness2_vsl.pdf", replace as(pdf)


* VSL per life-year at age 70
local graph_options `"legend(label(1 "q=1, no medical spending") on) graphregion(fcolor(white))"'
use "`simulations'" if age==70, clear
collapse (mean) VSL VSLY VSLY_LE, by(state LE QALE scen) fast

sort scen LE
label var LE "Life expectancy at age 70 (years)"
graph twoway connected VSLY_LE LE if scen=="robustness_q_1.25", `plot3' ytitle("Thousands of dollars", size(medlarge)) `graph_options'
graph export "$Longevity/results/figures/robustness2_mc_vsly_age70.pdf", replace as(pdf)

* VSI per QALY at age 70
use "`vsiy'", clear

collapse (mean) VSIY_LE, by(state_sick LE_sick scen) fast
append using "`vsl_70'"

sort scen LE_sick
format VSIY_LE %12.0fc
label var LE_sick "Life expectancy when ill (years)"

graph twoway connected VSIY_LE LE_sick if scen=="robustness_q_1.25", ytitle("Thousands of dollars") `plot3' `graph_options' text(114 0.25 "(death)", place(e))
graph export "$Longevity/results/figures/robustness2_mc_vsiy_age70.pdf", replace as(pdf)

******************************
* Other supporting analysis
******************************

* Figure \ref{F - MC VSL variance - state1} illustrates VSL over the life cycle for the subset (44\%) of individuals who were in health state 1 at age 50. 
insheet using "$Longevity/results/intermediate/base_1.25/wealth_nsims.csv", clear
assert abs(pct-44.47)<0.01 if health_state==1

** EOF




