* Supplementary packages employed by Stata
adopath ++ "$Longevity/scripts/libraries/stata"

tempfile t vsl_70
local FEM_data "$Longevity/data/FEM/no_inflation_or_mort_decline"
local FEM_input  "$Longevity/processed/fem"
local FEM_output "$Longevity/results/intermediate/base_1.25"

local texsave_settings "replace autonumber nofix"


***
* Mean, 5th percentile, and 95th percentile of VSL, by age
***
use "`FEM_output'/simulations_processed.dta", clear

* 22,214 healthy adults (state 1) at age 50
count if age==50
assert r(N)==22214

replace VSL = VSL/1000
collapse (mean) mean_VSL=VSL (p5) p5_VSL=VSL (p95) p95_VSL=VSL, by(age) fast


* "By age 70, the VSL inter-vigintile range spans \$1.9 to \$2.9 million."
assert abs(p5_VSL - 1918.0107)<1 if age==70
assert abs(p95_VSL - 2903.012)<1 if age==70

format mean_VSL %12.0fc
label var mean_VSL "Mean"
label var p5_VSL "5th percentile"
label var p95_VSL "95th percentile"
label var age "Age"
graph twoway line mean_VSL p5_VSL p95_VSL age, lpattern(solid shortdash shortdash) lwidth(thick medthick medthick) lcolor(blue red red) ytitle(" ") graphregion(color(white)) ylabel(0(2000)7000, labsize(large)) xlabel(, labsize(large)) xtitle(,size(large)) title("Thousands of dollars", placement(left) span margin(bottom) size(medium)) legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_vsl_variance.pdf", replace as(pdf)

***
* [All health states]: Mean, 5th percentile, and 95th percentile of VSL, by age
***
use "`FEM_output'/simulations_processed_allstates.dta", clear
replace VSL = VSL/1000

collapse (mean) mean_VSL=VSL (p5) p5_VSL=VSL (p95) p95_VSL=VSL, by(age) fast

* At age 50, the inter-vigintile range spans $1.8 million to $6.8 million.
assert abs(p5_VSL-1799.2059)<0.1 if age==50
assert abs(p95_VSL-6830.5518)<0.1 if age==50

* At age 70, the inter-vigintile range spans $0.4 million to $2.9 million.
assert abs(p5_VSL - 393.71564)<1 if age==70
assert abs(p95_VSL - 2852.21342)<1 if age==70


local yaxis_options `"yscale(range(0 500)) ylabel(0(250)750, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) title("VSL per QALY (thousands of dollars)", placement(left) span margin(bottom) size(medium)) ytitle("")"'

format mean_VSL %12.0fc
label var mean_VSL "Mean"
label var p5_VSL "5th percentile"
label var p95_VSL "95th percentile"
label var age "Age"
graph twoway line mean_VSL p5_VSL p95_VSL age, lpattern(solid shortdash shortdash) lwidth(thick medthick medthick) lcolor(blue red red) ytitle(" ") graphregion(color(white)) ylabel(0(2000)7000, labsize(large)) xlabel(, labsize(large)) xtitle(,size(large)) title("Thousands of dollars", placement(left) span margin(bottom) size(medium)) legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_vsl_variance_allstates.pdf", replace as(pdf)

*******
* Shocks
*******

* LE and QALY by age/state (descriptive stats)
insheet using "`FEM_output'/age_state_le_qaly.csv", comma clear
drop v1
replace v2 = v2+49
ren v2 age
ren v3 state
ren v4 LE
ren v5 QALE

assert QALE<LE
tempfile le_qaly
save "`le_qaly'", replace


* "Quality-adjusted life expectancy for a 70-year-old in perfect health is equal to 10.96 years."
keep if age==70 & state==1
assert abs(QALE-10.95534)<0.001

***
* VSL shocks
***
use "`FEM_output'/simulations_processed.dta", clear
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) nogenerate
replace VSL = VSL/1000
gen VSLY = VSL/QALE
label var VSLY "VSL per QALY (thousands of dollars)"

assert VSL>0
bysort sim (age): gen shock = state!=state[_n-1] & _n!=1
bysort sim (age): gen vsl_up = shock==1 & VSL>VSL[_n-1]
bysort sim (age): gen vsl_diff = VSL-VSL[_n-1] if shock==1
bysort sim (age): gen vsly_diff = VSLY-VSLY[_n-1] if shock==1

count if shock==1
local num_shocks = trim("`: di %11.0gc r(N)'")
assert "`num_shocks'"=="57,981"

format vsl_diff %12.0fc
summ vsl_diff, detail
local vsl_diff_mean = trim("`: di %4.1fc r(mean)'")
local vsl_diff_5  = trim("`: di %4.1fc r(p5)'")
local vsl_diff_95  = trim("`: di %4.1fc r(p95)'")

summ VSL if shock[_n+1]==1
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")



summ vsly_diff, detail
local vsly_diff_mean = trim("`: di %4.1fc r(mean)'")
local vsl_diff_5  = trim("`: di %4.1fc r(p5)'")
local vsl_diff_95  = trim("`: di %4.1fc r(p95)'")

summ VSLY if shock[_n+1]==1
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")



***
* VSL and VSL per QALY at age 70
***
keep if age==70

collapse (mean) VSL VSLY, by(state LE QALE) fast
preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	keep state_sick QALE_sick vsi VSIY
	save "`vsl_70'", replace
restore

format VSL %12.0fc
label var LE "Life expectancy"
label var VSL "VSL (thousands of dollars)"
sort QALE
label var QALE "Life expectancy (QALYs)"
label var VSLY "VSL per QALY (thousands of dollars)"
label var VSL "VSL"
label var VSLY "VSL per QALY"

local yaxis_options `"yscale(range(0 500)) ylabel(0(250)750, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) title("VSL per QALY (thousands of dollars)", placement(left) span margin(bottom) size(medium)) ytitle("")"'
graph twoway connected VSLY QALE, `yaxis_options' lpattern(solid) lwidth(thick) msize(medlarge) lcolor(red) mcolor(red) graphregion(color(white))
graph export "$Longevity/results/figures/slide_vsl_vsly_age70.pdf", replace as(pdf)


***
* VSI at age 70 and state 1
***
use "`FEM_output'/sims_vsi_age70_processed.dta", clear
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_sick

ren state state_sick
gen state = 1
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_healthy

gen diff = QALE_healthy - QALE_sick

assert diff<0.001 if state_sick==1
drop if state_sick==1

assert diff>0
assert diff<QALE_healthy
gen VSIY = vsi/diff

collapse (mean) VSIY vsi, by(state_sick QALE_sick) fast
replace VSIY = VSIY/1000
replace vsi = vsi/1000

append using "`vsl_70'"

sort QALE_sick


format VSIY %12.0fc
label var VSIY "VSI per QALY (thousands of dollars)"
label var QALE_sick "Life expectancy after falling ill (QALYs)"

format vsi %12.0fc
label var vsi "VSI"

local yaxis_options `"yscale(range(0 250)) ylabel(0(50)250, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) title("VSI per QALY (thousands of dollars)", placement(left) span margin(bottom) size(medium)) ytitle(" ")"'

local yaxis_options `"yscale(range(220 280)) ylabel(220(20)280, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) title("VSI per QALY (thousands of dollars)", placement(left) span margin(bottom) size(medium)) ytitle(" ")"'
graph twoway connected VSIY QALE_sick, `yaxis_options' lpattern(solid) lwidth(thick) msize(medlarge) lcolor(red) mcolor(red) graphregion(color(white))

graph export "$Longevity/results/figures/slide_vsi_vsiy_age70.pdf", replace as(pdf)

*******
* Spending shocks
*******

use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear
keep  age c_oopmd VSL_oopmd VSL_alt
order age c_oopmd VSL_oopmd VSL_alt

replace c_oopmd = c_oopmd/1000
replace VSL_oopmd = VSL_oopmd/1000
replace VSL_alt = VSL_alt/1000

label var c_oopmd "Consumption"
label var VSL_oopmd "VSL"
label var VSL_alt "VSL (additional wealth shock)"
label var age "Age"

format c_oopmd %12.0fc
format VSL_oopmd %12.0fc

keep if age<=75
graph twoway line c_oopmd age, lpattern(shortdash) lwidth(thick) lcolor(blue) || line VSL_oopmd VSL_alt age, yaxis(2) ytitle("Consumption (thousands of dollars)", axis(1) size(medlarge)) ytitle("VSL (thousands of dollars)", axis(2) size(medlarge)) lwidth(thick thick) lpattern(solid dot) lcolor(red black) graphregion(fcolor(white)) yscale(range(0) axis(1)) yscale(range(0) axis(2)) ylabel(0(25)100, axis(1) labsize(large))  ylabel(0(2000)6000, axis(2) labsize(large)) xlabel(, labsize(large)) xtitle(,size(large))
graph export "$Longevity/results/figures/slide_c_vsl_shock.pdf", replace as(pdf)



***********************************
* Spending summary statistics figure
***********************************

use "`FEM_data'/baseline_cohort_oopmd_1yr.dta", clear
ren l2health health_state
keep if age<99
replace oopmd = oopmd/1000

keep if inlist(health_state,1,20)

reshape wide oopmd, i(age) j(health_state)

label var oopmd1 "Healthy (state 1)"
label var oopmd20 "Sick (state 20)"

local yaxis_options `""'

graph twoway line oopmd1 oopmd20 age, lpattern(solid shortdash) lwidth(thick thick) lcolor(red blue) xtitle("Age", size(vlarge)) ytitle(" ", size(medlarge)) graphregion(fcolor(white)) ylabel(, labsize(vlarge)) xlabel(, labsize(vlarge)) title("Thousands of dollars", placement(left) span margin(bottom) size(medium))
graph export "$Longevity/results/figures/slide_medical_spending.pdf", as(pdf) replace


***********************************
* Robustness checks
***********************************
local FEM_output "$Longevity/results/intermediate"
tempfile cons_vsl simulations vsiy

local replace
qui foreach scen in base_0.8 base_1.25 base_1.5 bequest_1.25 robustness_q_1.25 {
	
	***
	* consumption/VSL shock
	***
	use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear	
	gen scen = "`scen'"
	
	keep if age<=75
	replace c_oopmd = c_oopmd/1000
	replace VSL_oopmd = VSL_oopmd/1000
	label var age "Age"

	format c_oopmd %12.0fc
	format VSL_oopmd %12.0fc	
	
	if "`replace'"!="" append using "`cons_vsl'"
	save "`cons_vsl'", `replace'
	
	***
	* Simulations
	***
	use "`FEM_output'/`scen'/simulations_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) nogenerate

	replace VSL = VSL/1000
	gen VSLY = VSL/QALE
	label var VSLY "VSL per QALY (thousands of dollars)"
	
	gen VSLY_LE = VSL/LE
	label var VSLY_LE "VSL per LY (thousands of dollars)"

	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`simulations'"
	save "`simulations'", `replace'
	
	***
	* VSIY
	*** 
	use "`FEM_output'/`scen'/sims_vsi_age70_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_sick
	ren LE LE_sick

	ren state state_sick
	gen state = 1
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_healthy
	ren LE LE_healthy

	gen diff    = QALE_healthy - QALE_sick
	gen diff_LE = LE_healthy - LE_sick

	assert diff<0.001 if state_sick==1
	assert diff_LE<0.001 if state_sick==1
	drop if state_sick==1

	assert diff   >0
	assert diff_LE>0
	assert diff   <QALE_healthy
	assert diff_LE<LE_healthy

	replace vsi = vsi/1000
	gen VSIY    = vsi/diff
	gen VSIY_LE = vsi/diff_LE
	
	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`vsiy'"
	save "`vsiy'", `replace'	
	
	local replace replace
}

local yaxis_options `"yscale(range(0 250)) ylabel(0(50)250, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) title("VSI per QALY (thousands of dollars)", placement(left) span margin(bottom) size(medium)) ytitle("")"'

local graph_options `"legend(label(1 "{&gamma}=0.8") label(2 "{&gamma}=1.25 (baseline)") label(3 "{&gamma}=1.5") label(4 "Bequest")) graphregion(fcolor(white)) ylabel(, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large))"'
local common_opts "lwidth(thick) msize(medlarge)"
local plot1 "lpattern(shortdash)    lcolor(green) mcolor(green) msymbol(X)   `common_opts'"
local plot2 "lpattern(solid)        lcolor(red)   mcolor(red)   msymbol(circle)   `common_opts'"
local plot3 "lpattern(shortdash)    lcolor(blue)  mcolor(blue)  msymbol(square)   `common_opts'"
local plot4 "lpattern(longdash_dot) lcolor(black) mcolor(black) msymbol(triangle) `common_opts'"

***********************************
* First set of robustness figures: vary gamma and vary bequest motive
***********************************


* VSL per QALY at age 70
use "`simulations'" if age==70, clear
collapse (mean) VSL VSLY VSLY_LE, by(state LE QALE scen) fast

preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	gen LE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	gen VSIY_LE = vsi/LE
	keep *_sick vsi VSIY VSIY_LE scen
	save "`vsl_70'", replace
restore

sort scen QALE
label var QALE "Life expectancy (QALYs)"

graph twoway connected VSLY QALE if scen=="base_0.8", lpattern(blank) msymbol(none) ytitle(" ") || connected VSLY QALE if scen=="base_1.25", `plot2' || connected VSLY QALE if scen=="base_1.5", lpattern(blank) msymbol(none) || connected VSLY QALE if scen=="bequest_1.25", lpattern(blank) msymbol(none) legend(label(1 "        ") label(2 "{&gamma}=1.25 (baseline)") label(3 "        ") label(4 "        ")) graphregion(fcolor(white)) ylabel(, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_bl_robustness_vsly_age70.pdf", replace as(pdf)


graph twoway connected VSLY QALE if scen=="base_0.8", `plot1' ytitle(" ") || connected VSLY QALE if scen=="base_1.25", `plot2' || connected VSLY QALE if scen=="base_1.5", `plot3' || connected VSLY QALE if scen=="bequest_1.25", `plot4' `graph_options' legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_robustness_vsly_age70.pdf", replace as(pdf)

* VSI per QALY at age 70
use "`vsiy'", clear

collapse (mean) VSIY, by(state_sick QALE_sick scen) fast
append using "`vsl_70'"

sort scen QALE_sick
format VSIY %12.0fc
label var QALE_sick "Life expectancy (QALYs)"

graph twoway connected VSIY QALE_sick if scen=="base_0.8", lpattern(blank) msymbol(none) ytitle(" ") yscale(range(150 300)) ylabel(150(50)300) || connected VSIY QALE_sick if scen=="base_1.25", `plot2' || connected VSIY QALE_sick if scen=="base_1.5",  lpattern(blank) msymbol(none) || connected VSIY QALE_sick if scen=="bequest_1.25",  lpattern(blank) msymbol(none) legend(label(1 "        ") label(2 "{&gamma}=1.25 (baseline)") label(3 "        ") label(4 "        ")) graphregion(fcolor(white)) ylabel(, labsize(vlarge)) xlabel(, labsize(vlarge)) xtitle(,size(large)) legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_bl_robustness_vsiy_age70.pdf", replace as(pdf)

graph twoway connected VSIY QALE_sick if scen=="base_0.8", `plot1' ytitle(" ") yscale(range(150 300)) ylabel(150(50)300) || connected VSIY QALE_sick if scen=="base_1.25", `plot2' || connected VSIY QALE_sick if scen=="base_1.5", `plot3' || connected VSIY QALE_sick if scen=="bequest_1.25", `plot4' `graph_options' legend(ring(0) position(1))
graph export "$Longevity/results/figures/slide_robustness_vsiy_age70.pdf", replace as(pdf)




** EOF




